@@ -122,6 +122,13 @@ class API {
 		return self::getApi('application');
 	}
 
+	/**
+	 * @return CAutoregistration
+	 */
+	public static function Autoregistration() {
+		return self::getApi('autoregistration');
+	}
+
 	/**
 	 * @return CConfiguration
 	 */
