@@ -455,12 +455,16 @@ class CApiService {
 	 * @return array		The resulting SQL parts array
 	 */
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
-		$pkFieldId = $this->fieldId($this->pk($tableName), $tableAlias);
+		// If table do not have a primary key, use COUNT(*) to select number of rows.
+		$pk = $this->pk($tableName);
+		$pkFieldId = $this->fieldId($pk, $tableAlias);
 
 		// count
 		if (array_key_exists('countOutput', $options) && $options['countOutput']
 				&& !$this->requiresPostSqlFiltering($options)) {
-			$sqlParts['select'] = ['COUNT(DISTINCT '.$pkFieldId.') AS rowscount'];
+			$sqlParts['select'] = ($pk !== '')
+				? ['COUNT(DISTINCT '.$pkFieldId.') AS rowscount']
+				: ['COUNT(*) AS rowscount'];
 
 			// select columns used by group count
 			if (array_key_exists('groupCount', $options) && $options['groupCount']) {
@@ -472,7 +476,7 @@ class CApiService {
 		// custom output
 		elseif (is_array($options['output'])) {
 			// the pk field must always be included for the API to work properly
-			$sqlParts['select'] = [$pkFieldId];
+			$sqlParts['select'] = ($pk !== '') ? [$pkFieldId] : [];
 			foreach ($options['output'] as $field) {
 				if ($this->hasField($field, $tableName)) {
 					$sqlParts['select'][] = $this->fieldId($field, $tableAlias);
@@ -576,7 +580,7 @@ class CApiService {
 	 */
 	protected function applyQuerySortField($sortfield, $sortorder, $alias, array $sqlParts) {
 		// add sort field to select if distinct is used
-		if (count($sqlParts['from']) > 1
+		if ((count($sqlParts['from']) > 1 || (isset($sqlParts['left_join']) && count($sqlParts['left_join'])))
 				&& !str_in_array($alias.'.'.$sortfield, $sqlParts['select'])
 				&& !str_in_array($alias.'.*', $sqlParts['select'])) {
 
