@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -67,9 +67,10 @@ class CProblem extends CApiService {
 			'eventid_till'				=> null,
 			'acknowledged'				=> null,
 			'suppressed'				=> null,
+			'recent'					=> null,
+			'any'						=> null,	// (internal) true if need not filtred by r_eventid
 			'evaltype'					=> TAG_EVAL_TYPE_AND_OR,
 			'tags'						=> null,
-			'recent'					=> null,
 			'filter'					=> null,
 			'search'					=> null,
 			'searchByAny'				=> null,
@@ -279,8 +280,8 @@ class CProblem extends CApiService {
 
 		// tags
 		if ($options['tags'] !== null && $options['tags']) {
-			$sqlParts['where'][] = CEvent::getTagsWhereCondition($options['tags'], $options['evaltype'], 'problem_tag',
-				'pt', 'p', 'eventid'
+			$sqlParts['where'][] = CApiTagHelper::addWhereCondition($options['tags'], $options['evaltype'], 'p',
+				'problem_tag', 'eventid'
 			);
 		}
 
@@ -399,6 +400,22 @@ class CProblem extends CApiService {
 
 		$eventids = array_keys($result);
 
+		// Adding operational data.
+		if ($this->outputIsRequested('opdata', $options['output'])) {
+			$problems = DBFetchArrayAssoc(DBselect(
+				'SELECT p.eventid,p.clock,p.ns,t.triggerid,t.expression,t.opdata'.
+				' FROM problem p'.
+				' JOIN triggers t ON t.triggerid=p.objectid'.
+				' WHERE '.dbConditionInt('p.eventid', $eventids)
+			), 'eventid');
+
+			foreach ($result as $eventid => $problem) {
+				$result[$eventid]['opdata'] = ($problems[$eventid]['opdata'] !== '')
+					? CMacrosResolverHelper::resolveTriggerOpdata($problems[$eventid], ['events' => true])
+					: '';
+			}
+		}
+
 		// adding acknowledges
 		if ($options['selectAcknowledges'] !== null) {
 			if ($options['selectAcknowledges'] != API_OUTPUT_COUNT) {
@@ -425,12 +442,11 @@ class CProblem extends CApiService {
 						' GROUP BY a.eventid'
 				), 'eventid');
 
-				foreach ($result as &$event) {
-					$event['acknowledges'] = array_key_exists($event['eventid'], $acknowledges)
-						? $acknowledges[$event['eventid']]['rowscount']
-						: 0;
+				foreach ($result as $eventid => $event) {
+					$result[$eventid]['acknowledges'] = array_key_exists($eventid, $acknowledges)
+						? $acknowledges[$eventid]['rowscount']
+						: '0';
 				}
-				unset($event);
 			}
 		}
 
@@ -452,8 +468,8 @@ class CProblem extends CApiService {
 			foreach ($result as &$problem) {
 				if (array_key_exists('suppression_data', $problem)) {
 					$problem['suppressed'] = $problem['suppression_data']
-						? ZBX_PROBLEM_SUPPRESSED_TRUE
-						: ZBX_PROBLEM_SUPPRESSED_FALSE;
+						? (string) ZBX_PROBLEM_SUPPRESSED_TRUE
+						: (string) ZBX_PROBLEM_SUPPRESSED_FALSE;
 				}
 				else {
 					$suppressed_eventids[] = $problem['eventid'];
@@ -469,8 +485,8 @@ class CProblem extends CApiService {
 				$suppressed_eventids = array_flip(zbx_objectValues($suppressed_events, 'eventid'));
 				foreach ($result as &$problem) {
 					$problem['suppressed'] = array_key_exists($problem['eventid'], $suppressed_eventids)
-						? ZBX_PROBLEM_SUPPRESSED_TRUE
-						: ZBX_PROBLEM_SUPPRESSED_FALSE;
+						? (string) ZBX_PROBLEM_SUPPRESSED_TRUE
+						: (string) ZBX_PROBLEM_SUPPRESSED_FALSE;
 				}
 				unset($problem);
 			}
@@ -485,6 +501,43 @@ class CProblem extends CApiService {
 			unset($row);
 		}
 
+		// Resolve webhook urls.
+		if ($this->outputIsRequested('urls', $options['output'])) {
+			$tags_options = [
+				'output' => ['eventid', 'tag', 'value'],
+				'filter' => ['eventid' => $eventids]
+			];
+			$tags = DBselect(DB::makeSql('problem_tag', $tags_options));
+
+			$events = [];
+
+			foreach ($result as $event) {
+				$events[$event['eventid']]['tags'] = [];
+			}
+
+			while ($tag = DBfetch($tags)) {
+				$events[$tag['eventid']]['tags'][] = [
+					'tag' => $tag['tag'],
+					'value' => $tag['value']
+				];
+			}
+
+			$urls = DB::select('media_type', [
+				'output' => ['event_menu_url', 'event_menu_name'],
+				'filter' => [
+					'type' => MEDIA_TYPE_WEBHOOK,
+					'status' => MEDIA_TYPE_STATUS_ACTIVE,
+					'show_event_menu' => ZBX_EVENT_MENU_SHOW
+				]
+			]);
+
+			$events = CMacrosResolverHelper::resolveMediaTypeUrls($events, $urls);
+
+			foreach ($events as $eventid => $event) {
+				$result[$eventid]['urls'] = $event['urls'];
+			}
+		}
+
 		// Adding event tags.
 		if ($options['selectTags'] !== null && $options['selectTags'] != API_OUTPUT_COUNT) {
 			if ($options['selectTags'] === API_OUTPUT_EXTEND) {
@@ -520,7 +573,7 @@ class CProblem extends CApiService {
 	 * @param array $usrgrpids
 	 * @param array $sqlParts
 	 *
-	 * @return string
+	 * @return array
 	 */
 	protected static function addTagFilterSqlParts(array $usrgrpids, array $sqlParts) {
 		$tag_filters = CEvent::getTagFilters($usrgrpids);
