@@ -528,7 +528,8 @@ class CTemplate extends CHostGeneral {
 
 			$templateCopy = $template;
 
-			$template['templates_link'] = isset($template['templates']) ? $template['templates'] : null;
+			$template['templates_link'] = array_key_exists('templates', $template) ? $template['templates'] : null;
+
 			unset($template['templates'], $template['templateid'], $templateCopy['templates']);
 			$template['templates'] = [$templateCopy];
 
