@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -67,6 +67,7 @@ class CTrigger extends CTriggerGeneral {
 			'applicationids'				=> null,
 			'functions'						=> null,
 			'inherited'						=> null,
+			'dependent'						=> null,
 			'templated'						=> null,
 			'monitored'						=> null,
 			'active'						=> null,
@@ -85,6 +86,8 @@ class CTrigger extends CTriggerGeneral {
 			'host'							=> null,
 			'only_true'						=> null,
 			'min_severity'					=> null,
+			'evaltype'						=> TAG_EVAL_TYPE_AND_OR,
+			'tags'							=> null,
 			'filter'						=> null,
 			'search'						=> null,
 			'searchByAny'					=> null,
@@ -104,6 +107,7 @@ class CTrigger extends CTriggerGeneral {
 			'selectDiscoveryRule'			=> null,
 			'selectLastEvent'				=> null,
 			'selectTags'					=> null,
+			'selectTriggerDiscovery'		=> null,
 			'countOutput'					=> false,
 			'groupCount'					=> false,
 			'preservekeys'					=> false,
@@ -136,7 +140,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// groupids
-		if (!is_null($options['groupids'])) {
+		if ($options['groupids'] !== null) {
 			zbx_value2array($options['groupids']);
 
 			sort($options['groupids']);
@@ -155,10 +159,10 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// templateids
-		if (!is_null($options['templateids'])) {
+		if ($options['templateids'] !== null) {
 			zbx_value2array($options['templateids']);
 
-			if (!is_null($options['hostids'])) {
+			if ($options['hostids'] !== null) {
 				zbx_value2array($options['hostids']);
 				$options['hostids'] = array_merge($options['hostids'], $options['templateids']);
 			}
@@ -168,7 +172,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// hostids
-		if (!is_null($options['hostids'])) {
+		if ($options['hostids'] !== null) {
 			zbx_value2array($options['hostids']);
 
 			$sqlParts['from']['functions'] = 'functions f';
@@ -183,14 +187,14 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// triggerids
-		if (!is_null($options['triggerids'])) {
+		if ($options['triggerids'] !== null) {
 			zbx_value2array($options['triggerids']);
 
 			$sqlParts['where']['triggerid'] = dbConditionInt('t.triggerid', $options['triggerids']);
 		}
 
 		// itemids
-		if (!is_null($options['itemids'])) {
+		if ($options['itemids'] !== null) {
 			zbx_value2array($options['itemids']);
 
 			$sqlParts['from']['functions'] = 'functions f';
@@ -203,7 +207,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// applicationids
-		if (!is_null($options['applicationids'])) {
+		if ($options['applicationids'] !== null) {
 			zbx_value2array($options['applicationids']);
 
 			$sqlParts['from']['functions'] = 'functions f';
@@ -214,16 +218,16 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// functions
-		if (!is_null($options['functions'])) {
+		if ($options['functions'] !== null) {
 			zbx_value2array($options['functions']);
 
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
-			$sqlParts['where'][] = dbConditionString('f.function', $options['functions']);
+			$sqlParts['where'][] = dbConditionString('f.name', $options['functions']);
 		}
 
 		// monitored
-		if (!is_null($options['monitored'])) {
+		if ($options['monitored'] !== null) {
 			$sqlParts['where']['monitored'] = 'NOT EXISTS ('.
 					'SELECT NULL'.
 					' FROM functions f,items i,hosts h'.
@@ -239,7 +243,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// active
-		if (!is_null($options['active'])) {
+		if ($options['active'] !== null) {
 			$sqlParts['where']['active'] = 'NOT EXISTS ('.
 					'SELECT NULL'.
 					' FROM functions f,items i,hosts h'.
@@ -252,7 +256,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// maintenance
-		if (!is_null($options['maintenance'])) {
+		if ($options['maintenance'] !== null) {
 			$sqlParts['where'][] = ($options['maintenance'] == 0 ? 'NOT ' : '').
 					'EXISTS ('.
 						'SELECT NULL'.
@@ -266,17 +270,17 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// lastChangeSince
-		if (!is_null($options['lastChangeSince'])) {
+		if ($options['lastChangeSince'] !== null) {
 			$sqlParts['where']['lastchangesince'] = 't.lastchange>'.zbx_dbstr($options['lastChangeSince']);
 		}
 
 		// lastChangeTill
-		if (!is_null($options['lastChangeTill'])) {
+		if ($options['lastChangeTill'] !== null) {
 			$sqlParts['where']['lastchangetill'] = 't.lastchange<'.zbx_dbstr($options['lastChangeTill']);
 		}
 
 		// withUnacknowledgedEvents
-		if (!is_null($options['withUnacknowledgedEvents'])) {
+		if ($options['withUnacknowledgedEvents'] !== null) {
 			$sqlParts['where']['unack'] = 'EXISTS ('.
 					'SELECT NULL'.
 					' FROM events e'.
@@ -289,7 +293,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// withAcknowledgedEvents
-		if (!is_null($options['withAcknowledgedEvents'])) {
+		if ($options['withAcknowledgedEvents'] !== null) {
 			$sqlParts['where']['ack'] = 'NOT EXISTS ('.
 					'SELECT NULL'.
 					' FROM events e'.
@@ -302,7 +306,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// templated
-		if (!is_null($options['templated'])) {
+		if ($options['templated'] !== null) {
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['from']['items'] = 'items i';
 			$sqlParts['from']['hosts'] = 'hosts h';
@@ -319,7 +323,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// inherited
-		if (!is_null($options['inherited'])) {
+		if ($options['inherited'] !== null) {
 			if ($options['inherited']) {
 				$sqlParts['where'][] = 't.templateid IS NOT NULL';
 			}
@@ -328,13 +332,31 @@ class CTrigger extends CTriggerGeneral {
 			}
 		}
 
+		// dependent
+		if ($options['dependent'] !== null) {
+			if ($options['dependent']) {
+				$sqlParts['where'][] = 'EXISTS ('.
+					'SELECT NULL'.
+					' FROM trigger_depends td'.
+					' WHERE td.triggerid_down=t.triggerid'.
+				')';
+			}
+			else {
+				$sqlParts['where'][] = 'NOT EXISTS ('.
+					'SELECT NULL'.
+					' FROM trigger_depends td'.
+					' WHERE td.triggerid_down=t.triggerid'.
+				')';
+			}
+		}
+
 		// search
 		if (is_array($options['search'])) {
 			zbx_db_search('triggers t', $options, $sqlParts);
 		}
 
 		// filter
-		if (is_null($options['filter'])) {
+		if ($options['filter'] === null) {
 			$options['filter'] = [];
 		}
 
@@ -348,7 +370,7 @@ class CTrigger extends CTriggerGeneral {
 
 			$this->dbFilter('triggers t', $options, $sqlParts);
 
-			if (isset($options['filter']['host']) && !is_null($options['filter']['host'])) {
+			if (array_key_exists('host', $options['filter']) && $options['filter']['host'] !== null) {
 				zbx_value2array($options['filter']['host']);
 
 				$sqlParts['from']['functions'] = 'functions f';
@@ -360,7 +382,7 @@ class CTrigger extends CTriggerGeneral {
 				$sqlParts['where']['host'] = dbConditionString('h.host', $options['filter']['host']);
 			}
 
-			if (isset($options['filter']['hostid']) && !is_null($options['filter']['hostid'])) {
+			if (array_key_exists('hostid', $options['filter']) && $options['filter']['hostid'] !== null) {
 				zbx_value2array($options['filter']['hostid']);
 
 				$sqlParts['from']['functions'] = 'functions f';
@@ -372,11 +394,11 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// group
-		if (!is_null($options['group'])) {
+		if ($options['group'] !== null) {
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['from']['items'] = 'items i';
 			$sqlParts['from']['hosts_groups'] = 'hosts_groups hg';
-			$sqlParts['from']['groups'] = 'groups g';
+			$sqlParts['from']['hstgrp'] = 'hstgrp g';
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
 			$sqlParts['where']['fi'] = 'f.itemid=i.itemid';
 			$sqlParts['where']['hgi'] = 'hg.hostid=i.hostid';
@@ -385,7 +407,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// host
-		if (!is_null($options['host'])) {
+		if ($options['host'] !== null) {
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['from']['items'] = 'items i';
 			$sqlParts['from']['hosts'] = 'hosts h';
@@ -396,7 +418,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// only_true
-		if (!is_null($options['only_true'])) {
+		if ($options['only_true'] !== null) {
 			$config = select_config();
 			$sqlParts['where']['ot'] = '((t.value='.TRIGGER_VALUE_TRUE.')'.
 				' OR ((t.value='.TRIGGER_VALUE_FALSE.')'.
@@ -406,10 +428,17 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// min_severity
-		if (!is_null($options['min_severity'])) {
+		if ($options['min_severity'] !== null) {
 			$sqlParts['where'][] = 't.priority>='.zbx_dbstr($options['min_severity']);
 		}
 
+		// tags
+		if ($options['tags'] !== null && $options['tags']) {
+			$sqlParts['where'][] = CApiTagHelper::addWhereCondition($options['tags'], $options['evaltype'], 't',
+				'trigger_tag', 'triggerid'
+			);
+		}
+
 		// limit
 		if (!zbx_ctype_digit($options['limit']) || !$options['limit']) {
 			$options['limit'] = null;
@@ -436,7 +465,7 @@ class CTrigger extends CTriggerGeneral {
 
 		// return count for post SQL filtered result sets
 		if ($options['countOutput']) {
-			return count($result);
+			return (string) count($result);
 		}
 
 		if ($result) {
@@ -444,13 +473,13 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// expandDescription
-		if (!is_null($options['expandDescription']) && $result && array_key_exists('description', reset($result))) {
+		if ($options['expandDescription'] !== null && $result && array_key_exists('description', reset($result))) {
 			$result = CMacrosResolverHelper::resolveTriggerNames($result);
 		}
 
 		// expandComment
-		if (!is_null($options['expandComment']) && $result && array_key_exists('comments', reset($result))) {
-			$result = CMacrosResolverHelper::resolveTriggerDescriptions($result);
+		if ($options['expandComment'] !== null && $result && array_key_exists('comments', reset($result))) {
+			$result = CMacrosResolverHelper::resolveTriggerDescriptions($result, ['sources' => ['comments']]);
 		}
 
 		// expand expressions
@@ -560,7 +589,7 @@ class CTrigger extends CTriggerGeneral {
 			$this->inherit($trigger);
 
 			// replace dependencies
-			if (isset($trigger['dependencies'])) {
+			if (array_key_exists('dependencies', $trigger)) {
 				$this->deleteDependencies($trigger);
 
 				if ($trigger['dependencies']) {
@@ -582,151 +611,58 @@ class CTrigger extends CTriggerGeneral {
 	/**
 	 * Delete triggers.
 	 *
-	 * @param array $triggerIds
-	 * @param bool  $nopermissions
+	 * @param array $triggerids
 	 *
 	 * @return array
 	 */
-	public function delete(array $triggerIds, $nopermissions = false) {
-		$this->validateDelete($triggerIds, $nopermissions);
+	public function delete(array $triggerids) {
+		$this->validateDelete($triggerids, $db_triggers);
 
-		// get child triggers
-		$parentTriggerIds = $triggerIds;
+		CTriggerManager::delete($triggerids);
 
-		do {
-			$dbItems = DBselect('SELECT triggerid FROM triggers WHERE '.dbConditionInt('templateid', $parentTriggerIds));
-			$parentTriggerIds = [];
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_TRIGGER, $db_triggers);
 
-			while ($dbTrigger = DBfetch($dbItems)) {
-				$parentTriggerIds[] = $dbTrigger['triggerid'];
-				$triggerIds[] = $dbTrigger['triggerid'];
-			}
-		} while ($parentTriggerIds);
-
-		// select all triggers which are deleted (including children)
-		$delTriggers = $this->get([
-			'output' => ['triggerid', 'description'],
-			'triggerids' => $triggerIds,
-			'nopermissions' => true,
-			'selectHosts' => ['name']
-		]);
-
-		// TODO: REMOVE info
-		foreach ($delTriggers as $trigger) {
-			info(_s('Deleted: Trigger "%1$s" on "%2$s".', $trigger['description'],
-				implode(', ', zbx_objectValues($trigger['hosts'], 'name'))
-			));
-
-			add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_TRIGGER, $trigger['triggerid'], $trigger['description'],
-				null, null, null
-			);
-		}
-
-		// execute delete
-		$this->deleteByIds($triggerIds);
-
-		return ['triggerids' => $triggerIds];
+		return ['triggerids' => $triggerids];
 	}
 
 	/**
 	 * Validates the input parameters for the delete() method.
 	 *
-	 * @param array		$triggerids			Trigger IDs.
-	 * @param bool		$nopermissions		If set to true permissions will not be checked.
+	 * @param array $triggerids   [IN/OUT]
+	 * @param array $db_triggers  [OUT]
 	 *
 	 * @throws APIException if the input is invalid.
 	 */
-	protected function validateDelete(array $triggerids, $nopermissions) {
-		if (!$triggerids) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+	protected function validateDelete(array &$triggerids, array &$db_triggers = null) {
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $triggerids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		if (!$nopermissions) {
-			$this->checkPermissions($triggerids);
-			$this->checkNotInherited($triggerids);
-		}
-	}
-
-	/**
-	 * Delete trigger by ids.
-	 *
-	 * @param array $triggerIds
-	 */
-	protected function deleteByIds(array $triggerIds) {
-		// disable actions
-		$actionIds = [];
-
-		$dbActions = DBselect(
-			'SELECT DISTINCT actionid'.
-			' FROM conditions'.
-			' WHERE conditiontype='.CONDITION_TYPE_TRIGGER.
-				' AND '.dbConditionString('value', $triggerIds)
-		);
-		while ($dbAction = DBfetch($dbActions)) {
-			$actionIds[$dbAction['actionid']] = $dbAction['actionid'];
-		}
-
-		DBexecute('UPDATE actions SET status='.ACTION_STATUS_DISABLED.' WHERE '.dbConditionInt('actionid', $actionIds));
-
-		// delete action conditions
-		DB::delete('conditions', [
-			'conditiontype' => CONDITION_TYPE_TRIGGER,
-			'value' => $triggerIds
+		$db_triggers = $this->get([
+			'output' => ['triggerid', 'description', 'expression', 'templateid'],
+			'triggerids' => $triggerids,
+			'editable' => true,
+			'preservekeys' => true
 		]);
 
-		if ($this->usedInItServices($triggerIds)) {
-			DB::update('services', [
-				'values' => [
-					'triggerid' => null,
-					'showsla' => SERVICE_SHOW_SLA_OFF
-				],
-				'where' => [
-					'triggerid' => $triggerIds
-				]
-			]);
-
-			updateItServices();
-		}
-
-		// Remove trigger sysmap elements.
-		$selementids = [];
-
-		$db_trigger_elements = DBselect(
-			'SELECT st.selementid'.
-			' FROM sysmap_element_trigger st'.
-			' WHERE '.dbConditionInt('st.triggerid', $triggerIds)
-		);
-
-		while ($db_trigger_element = DBfetch($db_trigger_elements)) {
-			$selementids[$db_trigger_element['selementid']] = true;
-		}
-
-		if ($selementids) {
-			DB::delete('sysmap_element_trigger', ['triggerid' => $triggerIds]);
-
-			$db_not_empty_elements = DBselect(
-				'SELECT st.selementid'.
-				' FROM sysmap_element_trigger st'.
-				' WHERE '.dbConditionInt('st.selementid', array_keys($selementids))
-			);
-			while ($db_not_empty_element = DBfetch($db_not_empty_elements)) {
-				unset($selementids[$db_not_empty_element['selementid']]);
+		foreach ($triggerids as $triggerid) {
+			if (!array_key_exists($triggerid, $db_triggers)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
 			}
 
-			DB::delete('sysmaps_elements', ['selementid' => array_keys($selementids)]);
-		}
+			$db_trigger = $db_triggers[$triggerid];
 
-		$insert = [];
-		foreach ($triggerIds as $triggerId) {
-			$insert[] = [
-				'tablename' => 'events',
-				'field' => 'triggerid',
-				'value' => $triggerId
-			];
+			if ($db_trigger['templateid'] != 0) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('Cannot delete templated trigger "%1$s:%2$s".', $db_trigger['description'],
+						CMacrosResolverHelper::resolveTriggerExpression($db_trigger['expression'])
+					)
+				);
+			}
 		}
-		DB::insertBatch('housekeeper', $insert);
-
-		parent::deleteByIds($triggerIds);
 	}
 
 	/**
@@ -735,20 +671,24 @@ class CTrigger extends CTriggerGeneral {
 	 * @throws APIException if the given dependencies are invalid
 	 *
 	 * @param array $triggersData
+	 * @param bool  $inherited
 	 */
-	protected function validateAddDependencies(array $triggersData) {
+	protected function validateAddDependencies(array $triggersData, $inherited = false) {
 		if (!$triggersData) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
 		}
 
 		$triggerids = array_unique(zbx_objectValues($triggersData, 'triggerid'));
 
+		$permission_check = $inherited
+			? ['nopermissions' => true]
+			: ['editable' => true];
+
 		$triggers = $this->get([
 			'output' => ['triggerid', 'description', 'flags'],
 			'triggerids' => $triggerids,
-			'editable' => true,
 			'preservekeys' => true
-		]);
+		] + $permission_check);
 
 		foreach ($triggerids as $triggerid) {
 			if (!array_key_exists($triggerid, $triggers)) {
@@ -781,7 +721,7 @@ class CTrigger extends CTriggerGeneral {
 			$depTtriggerIds[$dep['dependsOnTriggerid']] = $dep['dependsOnTriggerid'];
 		}
 
-		if ($depTtriggerIds) {
+		if (!$inherited && $depTtriggerIds) {
 			$count = $this->get([
 				'countOutput' => true,
 				'triggerids' => $depTtriggerIds
@@ -804,13 +744,15 @@ class CTrigger extends CTriggerGeneral {
 	 *
 	 * @param array $triggersData   an array of trigger dependency pairs, each pair in the form of
 	 *                              array('triggerid' => 1, 'dependsOnTriggerid' => 2)
+	 * @param bool  $inherited      Determines either to check permissions for added dependencies. Permissions are not
+	 *                              validated for inherited triggers.
 	 *
 	 * @return array
 	 */
-	public function addDependencies(array $triggersData) {
+	public function addDependencies(array $triggersData, $inherited = false) {
 		$triggersData = zbx_toArray($triggersData);
 
-		$this->validateAddDependencies($triggersData);
+		$this->validateAddDependencies($triggersData, $inherited);
 
 		foreach ($triggersData as $dep) {
 			$triggerId = $dep['triggerid'];
@@ -838,7 +780,7 @@ class CTrigger extends CTriggerGeneral {
 						$this->addDependencies([[
 							'triggerid' => $childTrigger['triggerid'],
 							'dependsOnTriggerid' => $newDep[$childTrigger['triggerid']]
-						]]);
+						]], true);
 					}
 				}
 			}
@@ -853,20 +795,24 @@ class CTrigger extends CTriggerGeneral {
 	 * @throws APIException if the given input is invalid
 	 *
 	 * @param array $triggers
+	 * @param bool  $inherited
 	 */
-	protected function validateDeleteDependencies(array $triggers) {
+	protected function validateDeleteDependencies(array $triggers, $inherited) {
 		if (!$triggers) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
 		}
 
 		$triggerids = array_unique(zbx_objectValues($triggers, 'triggerid'));
 
+		$permission_check = $inherited
+			? ['nopermissions' => true]
+			: ['editable' => true];
+
 		$triggers = $this->get([
 			'output' => ['triggerid', 'description', 'flags'],
 			'triggerids' => $triggerids,
-			'editable' => true,
 			'preservekeys' => true
-		]);
+		] + $permission_check);
 
 		foreach ($triggerids as $triggerid) {
 			if (!array_key_exists($triggerid, $triggers)) {
@@ -889,13 +835,15 @@ class CTrigger extends CTriggerGeneral {
 	 * Deletes all trigger dependencies from the given triggers and their children.
 	 *
 	 * @param array $triggers   an array of triggers with the 'triggerid' field defined
+	 * @param bool  $inherited  Determines either to check permissions for deleted dependencies. Permissions are not
+	 *                          validated for inherited triggers.
 	 *
 	 * @return array
 	 */
-	public function deleteDependencies(array $triggers) {
+	public function deleteDependencies(array $triggers, $inherited = false) {
 		$triggers = zbx_toArray($triggers);
 
-		$this->validateDeleteDependencies($triggers);
+		$this->validateDeleteDependencies($triggers, $inherited);
 
 		$triggerids = zbx_objectValues($triggers, 'triggerid');
 
@@ -908,7 +856,7 @@ class CTrigger extends CTriggerGeneral {
 				]
 			]);
 			if ($childTriggers) {
-				$this->deleteDependencies($childTriggers);
+				$this->deleteDependencies($childTriggers, true);
 			}
 
 			DB::delete('trigger_depends', [
@@ -1061,7 +1009,7 @@ class CTrigger extends CTriggerGeneral {
 			$depTemplateIds = zbx_toHash(zbx_objectValues($triggerDependencyTemplates, 'templateid'));
 
 			// run the check only if a templated trigger has dependencies on other templates
-			$triggerTemplateIds = zbx_toHash(zbx_objectValues($triggerTemplates, 'hostid'));
+			$triggerTemplateIds = zbx_toHash(zbx_objectValues($triggerTemplates, 'templateid'));
 			$tdiff = array_diff($depTemplateIds, $triggerTemplateIds);
 			if (!empty($triggerTemplateIds) && !empty($depTemplateIds) && !empty($tdiff)) {
 				$affectedTemplateIds = zbx_array_merge($triggerTemplateIds, $depTemplateIds);
@@ -1206,6 +1154,10 @@ class CTrigger extends CTriggerGeneral {
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
+		if (!$result) {
+			return $result;
+		}
+
 		$triggerids = array_keys($result);
 
 		// adding trigger dependencies
@@ -1334,6 +1286,34 @@ class CTrigger extends CTriggerGeneral {
 			}
 		}
 
+		// adding trigger discovery
+		if ($options['selectTriggerDiscovery'] !== null && $options['selectTriggerDiscovery'] !== API_OUTPUT_COUNT) {
+			foreach ($result as &$trigger) {
+				$trigger['triggerDiscovery'] = [];
+			}
+			unset($trigger);
+
+			$sql_select = ['triggerid'];
+			foreach (['parent_triggerid'] as $field) {
+				if ($this->outputIsRequested($field, $options['selectTriggerDiscovery'])) {
+					$sql_select[] = $field;
+				}
+			}
+
+			$trigger_discoveries = DBselect(
+				'SELECT '.implode(',', $sql_select).
+				' FROM trigger_discovery'.
+				' WHERE '.dbConditionInt('triggerid', $triggerids)
+			);
+
+			while ($trigger_discovery = DBfetch($trigger_discoveries)) {
+				$triggerid = $trigger_discovery['triggerid'];
+				unset($trigger_discovery['triggerid']);
+
+				$result[$triggerid]['triggerDiscovery'] = $trigger_discovery;
+			}
+		}
+
 		return $result;
 	}
 
@@ -1355,55 +1335,6 @@ class CTrigger extends CTriggerGeneral {
 		return $sqlParts;
 	}
 
-	/**
-	 * Checks if all of the given triggers are available for writing.
-	 *
-	 * @throws APIException     if a trigger is not writable or does not exist or is not normal
-	 *
-	 * @param array $triggerids
-	 */
-	protected function checkPermissions(array $triggerids) {
-		if ($triggerids) {
-			$triggerids = array_unique($triggerids);
-
-			$count = $this->get([
-				'countOutput' => true,
-				'triggerids' => $triggerids,
-				'editable' => true
-			]);
-
-			if ($count != count($triggerids)) {
-				self::exception(ZBX_API_ERROR_PERMISSIONS,
-					_('No permissions to referred object or it does not exist!')
-				);
-			}
-		}
-	}
-
-	/**
-	 * Checks that none of the given triggers is inherited from a template.
-	 *
-	 * @throws APIException     if one of the triggers is inherited
-	 *
-	 * @param array $triggerIds
-	 */
-	protected function checkNotInherited(array $triggerIds) {
-		$trigger = DBfetch(DBselect(
-			'SELECT t.triggerid,t.description,t.expression'.
-				' FROM triggers t'.
-				' WHERE '.dbConditionInt('t.triggerid', $triggerIds).
-				' AND t.templateid IS NOT NULL',
-			1
-		));
-		if ($trigger) {
-			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Cannot delete templated trigger "%1$s:%2$s".', $trigger['description'],
-					CMacrosResolverHelper::resolveTriggerExpression($trigger['expression'])
-				)
-			);
-		}
-	}
-
 	protected function requiresPostSqlFiltering(array $options) {
 		return $options['skipDependent'] !== null || $options['withLastEventUnacknowledged'] !== null;
 	}
@@ -1538,7 +1469,7 @@ class CTrigger extends CTriggerGeneral {
 		}
 
 		// withLastEventUnacknowledged
-		if (!is_null($options['withLastEventUnacknowledged'])) {
+		if ($options['withLastEventUnacknowledged'] !== null) {
 			$triggerIds = zbx_objectValues($triggers, 'triggerid');
 			$eventIds = [];
 			$eventsDb = DBselect(
@@ -1570,17 +1501,4 @@ class CTrigger extends CTriggerGeneral {
 
 		return $triggers;
 	}
-
-	/**
-	 * Returns true if at least one of the given triggers is used in services.
-	 *
-	 * @param array $triggerIds
-	 *
-	 * @return bool
-	 */
-	protected function usedInItServices(array $triggerIds) {
-		$query = DBselect('SELECT serviceid FROM services WHERE '.dbConditionInt('triggerid', $triggerIds), 1);
-
-		return (DBfetch($query) != false);
-	}
 }
