@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -69,7 +69,13 @@ class CXmlExportWriter extends CExportWriter {
 				$this->fromArray($value, $name);
 			}
 			elseif (!zbx_empty($value)) {
-				$this->xmlWriter->text($value);
+				// Value containing only whitespace characters should be saved as CDATA.
+				if (trim($value) === '') {
+					$this->xmlWriter->writeCData($value);
+				}
+				else {
+					$this->xmlWriter->text($value);
+				}
 			}
 
 			$this->xmlWriter->endElement();
@@ -125,7 +131,11 @@ class CXmlExportWriter extends CExportWriter {
 			'query_fields' => 'query_field',
 			'posts' => 'post_field',
 			'shapes' => 'shape',
-			'lines' => 'line'
+			'lines' => 'line',
+			'lld_macro_paths' => 'lld_macro_path',
+			'tls_accept' => 'option',
+			'media_types' => 'media_type',
+			'parameters' => 'parameter'
 		];
 
 		return isset($map[$name]) ? $map[$name] : false;
