@@ -319,7 +319,7 @@ class CJson {
 				 * escaping with a slash or encoding to UTF-8 where necessary
 				 */
 				for ($c = 0; $c < $strlen_var; ++$c) {
-					$ord_var_c = ord($var{$c});
+					$ord_var_c = ord($var[$c]);
 					switch (true) {
 						case $ord_var_c == 0x08:
 							$ascii .= '\b';
@@ -342,16 +342,16 @@ class CJson {
 							// falls through
 						case $ord_var_c == 0x5C:
 							// double quote, slash, slosh
-							$ascii .= '\\'.$var{$c};
+							$ascii .= '\\'.$var[$c];
 							break;
 						case ($ord_var_c >= 0x20 && $ord_var_c <= 0x7F):
 							// characters U-00000000 - U-0000007F (same as ASCII)
-							$ascii .= $var{$c};
+							$ascii .= $var[$c];
 							break;
 						case (($ord_var_c & 0xE0) == 0xC0):
 							// characters U-00000080 - U-000007FF, mask 110XXXXX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-							$char = pack('C*', $ord_var_c, ord($var{$c + 1}));
+							$char = pack('C*', $ord_var_c, ord($var[$c + 1]));
 							$c += 1;
 							$utf16 = $this->_utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -359,7 +359,7 @@ class CJson {
 						case (($ord_var_c & 0xF0) == 0xE0):
 							// characters U-00000800 - U-0000FFFF, mask 1110XXXX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-							$char = pack('C*', $ord_var_c, ord($var{$c + 1}), ord($var{$c + 2}));
+							$char = pack('C*', $ord_var_c, ord($var[$c + 1]), ord($var[$c + 2]));
 							$c += 2;
 							$utf16 = $this->_utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -367,7 +367,7 @@ class CJson {
 						case (($ord_var_c & 0xF8) == 0xF0):
 							// characters U-00010000 - U-001FFFFF, mask 11110XXX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-							$char = pack('C*', $ord_var_c, ord($var{$c + 1}), ord($var{$c + 2}), ord($var{$c + 3}));
+							$char = pack('C*', $ord_var_c, ord($var[$c + 1]), ord($var[$c + 2]), ord($var[$c + 3]));
 							$c += 3;
 							$utf16 = $this->_utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -376,10 +376,10 @@ class CJson {
 							// characters U-00200000 - U-03FFFFFF, mask 111110XX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
 							$char = pack('C*', $ord_var_c,
-										ord($var{$c + 1}),
-										ord($var{$c + 2}),
-										ord($var{$c + 3}),
-										ord($var{$c + 4}));
+										ord($var[$c + 1]),
+										ord($var[$c + 2]),
+										ord($var[$c + 3]),
+										ord($var[$c + 4]));
 							$c += 4;
 							$utf16 = $this->_utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -388,11 +388,11 @@ class CJson {
 							// characters U-04000000 - U-7FFFFFFF, mask 1111110X
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
 							$char = pack('C*', $ord_var_c,
-										ord($var{$c + 1}),
-										ord($var{$c + 2}),
-										ord($var{$c + 3}),
-										ord($var{$c + 4}),
-										ord($var{$c + 5}));
+										ord($var[$c + 1]),
+										ord($var[$c + 2]),
+										ord($var[$c + 3]),
+										ord($var[$c + 4]),
+										ord($var[$c + 5]));
 							$c += 5;
 							$utf16 = $this->_utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -516,7 +516,7 @@ class CJson {
 					$strlen_chrs = strlen($chrs);
 					for ($c = 0; $c < $strlen_chrs; ++$c) {
 						$substr_chrs_c_2 = substr($chrs, $c, 2);
-						$ord_chrs_c = ord($chrs{$c});
+						$ord_chrs_c = ord($chrs[$c]);
 						switch (true) {
 							case $substr_chrs_c_2 == '\b':
 								$utf8 .= chr(0x08);
@@ -544,7 +544,7 @@ class CJson {
 							case $substr_chrs_c_2 == '\\/':
 								if ($delim == '"' && $substr_chrs_c_2 != '\\\'' || $delim == "'"
 										&& $substr_chrs_c_2 != '\\"') {
-									$utf8 .= $chrs{++$c};
+									$utf8 .= $chrs[++$c];
 								}
 								break;
 							case preg_match('/\\\u[0-9A-F]{4}/i', substr($chrs, $c, 6)):
@@ -554,7 +554,7 @@ class CJson {
 								$c += 5;
 								break;
 							case $ord_chrs_c >= 0x20 && $ord_chrs_c <= 0x7F:
-								$utf8 .= $chrs{$c};
+								$utf8 .= $chrs[$c];
 								break;
 							case ($ord_chrs_c & 0xE0) == 0xC0:
 								// characters U-00000080 - U-000007FF, mask 110XXXXX
@@ -598,7 +598,7 @@ class CJson {
 				}
 				elseif (preg_match('/^\[.*\]$/s', $str) || preg_match('/^\{.*\}$/s', $str)) {
 					// array, or object notation
-					if ($str{0} == '[') {
+					if ($str[0] == '[') {
 						$stk = [self::IN_ARR];
 						$this->_level = self::IN_ARR;
 						$arr = [];
@@ -633,7 +633,7 @@ class CJson {
 						$top = end($stk);
 						$substr_chrs_c_2 = substr($chrs, $c, 2);
 
-						if ($c == $strlen_chrs || ($chrs{$c} == ',' && $top['what'] == self::SLICE)) {
+						if ($c == $strlen_chrs || ($chrs[$c] == ',' && $top['what'] == self::SLICE)) {
 							// found a comma that is not inside a string, array, etc.,
 							// OR we've reached the end of the character list
 							$slice = substr($chrs, $top['where'], $c - $top['where']);
@@ -692,33 +692,33 @@ class CJson {
 								}
 							}
 						}
-						elseif (($chrs{$c} == '"' || $chrs{$c} == "'") && $top['what'] != self::IN_STR) {
+						elseif (($chrs[$c] == '"' || $chrs[$c] == "'") && $top['what'] != self::IN_STR) {
 							// found a quote, and we are not inside a string
-							array_push($stk, ['what' => self::IN_STR, 'where' => $c, 'delim' => $chrs{$c}]);
+							array_push($stk, ['what' => self::IN_STR, 'where' => $c, 'delim' => $chrs[$c]]);
 						}
 						elseif (((strlen(substr($chrs, 0, $c)) - strlen(rtrim(substr($chrs, 0, $c), '\\'))) % 2 != 1)
-								&& $chrs{$c} == $top['delim'] && $top['what'] == self::IN_STR) {
+								&& $chrs[$c] == $top['delim'] && $top['what'] == self::IN_STR) {
 							// found a quote, we're in a string, and it's not escaped
 							// we know that it's not escaped because there is _not_ an
 							// odd number of backslashes at the end of the string so far
 							array_pop($stk);
 						}
-						elseif ($chrs{$c} == '['
+						elseif ($chrs[$c] == '['
 								&& in_array($top['what'], [self::SLICE, self::IN_ARR, self::IN_OBJ])) {
 							// found a left-bracket, and we are in an array, object, or slice
 							array_push($stk, ['what' => self::IN_ARR, 'where' => $c, 'delim' => false]);
 						}
-						elseif ($chrs{$c} == ']' && $top['what'] == self::IN_ARR) {
+						elseif ($chrs[$c] == ']' && $top['what'] == self::IN_ARR) {
 							// found a right-bracket, and we're in an array
 							$this->_level = null;
 							array_pop($stk);
 						}
-						elseif ($chrs{$c} == '{'
+						elseif ($chrs[$c] == '{'
 								&& in_array($top['what'], [self::SLICE, self::IN_ARR, self::IN_OBJ])) {
 							// found a left-brace, and we are in an array, object, or slice
 							array_push($stk, ['what' => self::IN_OBJ, 'where' => $c, 'delim' => false]);
 						}
-						elseif ($chrs{$c} == '}' && $top['what'] == self::IN_OBJ) {
+						elseif ($chrs[$c] == '}' && $top['what'] == self::IN_OBJ) {
 							// found a right-brace, and we're in an object
 							$this->_level = null;
 							array_pop($stk);
@@ -777,7 +777,7 @@ class CJson {
 		if (!$this->_config['bypass_mb'] && function_exists('mb_convert_encoding')) {
 			return mb_convert_encoding($utf16, 'UTF-8', 'UTF-16');
 		}
-		$bytes = (ord($utf16{0}) << 8) | ord($utf16{1});
+		$bytes = (ord($utf16[0]) << 8) | ord($utf16[1]);
 
 		switch (true) {
 			case ((0x7F & $bytes) == $bytes):
@@ -821,12 +821,12 @@ class CJson {
 			case 2:
 				// return a UTF-16 character from a 2-byte UTF-8 char
 				// see: http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-				return chr(0x07 & (ord($utf8{0}) >> 2)).chr((0xC0 & (ord($utf8{0}) << 6)) | (0x3F & ord($utf8{1})));
+				return chr(0x07 & (ord($utf8[0]) >> 2)).chr((0xC0 & (ord($utf8[0]) << 6)) | (0x3F & ord($utf8[1])));
 			case 3:
 				// return a UTF-16 character from a 3-byte UTF-8 char
 				// see: http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-				return chr((0xF0 & (ord($utf8{0}) << 4)) | (0x0F & (ord($utf8{1}) >> 2))).
-						chr((0xC0 & (ord($utf8{1}) << 6)) | (0x7F & ord($utf8{2})));
+				return chr((0xF0 & (ord($utf8[0]) << 4)) | (0x0F & (ord($utf8[1]) >> 2))).
+						chr((0xC0 & (ord($utf8[1]) << 6)) | (0x7F & ord($utf8[2])));
 		}
 		// ignoring UTF-32 for now, sorry
 		return '';
@@ -948,7 +948,7 @@ class CJson {
 		$this->_push(self::MODE_DONE);
 
 		for ($_the_index = 0; $_the_index < $len; $_the_index++) {
-			$b = $str{$_the_index};
+			$b = $str[$_the_index];
 			if (chr(ord($b) & 127) == $b) {
 				$c = $this->_ascii_class[ord($b)];
 				if ($c <= self::S_ERR) {
