@@ -172,10 +172,9 @@ class CScreenHostTriggers extends CScreenBase {
 
 		$filter = $filter + [
 			'show' => TRIGGERS_OPTION_IN_PROBLEM,
-			'maintenance' => 1,
 			'show_timeline' => 0,
 			'details' => 1,
-			'show_latest_values' => 0,
+			'show_opdata' => 0,
 			'sort_field' => '',
 			'sort_order' => ZBX_SORT_DOWN
 		];
@@ -214,29 +213,13 @@ class CScreenHostTriggers extends CScreenBase {
 		foreach ($data['triggers'] as $trigger) {
 			$hostids += $trigger['hosts'] ? array_fill_keys(zbx_objectValues($trigger['hosts'], 'hostid'), '') : [];
 		}
-		$hostids = array_keys($hostids);
 
 		$hosts = API::Host()->get([
-			'hostids' => $hostids,
-			'output' => ['hostid', 'name', 'maintenance_status', 'maintenance_type', 'maintenanceid'],
+			'output' => ['hostid', 'name', 'status'],
+			'hostids' => array_keys($hostids),
 			'preservekeys' => true
 		]);
 
-		$maintenanceids = [];
-		foreach ($hosts as $host) {
-			if ($host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON) {
-				$maintenanceids[$host['maintenanceid']] = true;
-			}
-		}
-
-		if ($maintenanceids) {
-			$maintenances = API::Maintenance()->get([
-				'maintenanceids' => array_keys($maintenanceids),
-				'output' => ['name', 'description'],
-				'preservekeys' => true
-			]);
-		}
-
 		$table = (new CTableInfo())->setHeader($header + [_('Age'), _('Info'), _('Ack'), _('Actions')]);
 
 		foreach ($data['problems'] as $problem) {
@@ -245,17 +228,7 @@ class CScreenHostTriggers extends CScreenBase {
 			// Host name with hint box.
 			$host = reset($trigger['hosts']);
 			$host = $hosts[$host['hostid']];
-			$host_name = (new CLinkAction($host['name']))
-				->setMenuPopup(CMenuPopupHelper::getHost($host['hostid']));
-
-			if ($host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON
-					&& array_key_exists($host['maintenanceid'], $maintenances)) {
-				$maintenance = $maintenances[$host['maintenanceid']];
-				$maintenance_icon = makeMaintenanceIcon($host['maintenance_type'], $maintenance['name'],
-					$maintenance['description']
-				);
-				$host_name = (new CSpan([$host_name, $maintenance_icon]))->addClass(ZBX_STYLE_REL_CONTAINER);
-			}
+			$host_name = (new CLinkAction($host['name']))->setMenuPopup(CMenuPopupHelper::getHost($host['hostid']));
 
 			// Info.
 			$info_icons = [];
@@ -273,7 +246,7 @@ class CScreenHostTriggers extends CScreenBase {
 					$info_icons[] = makeInformationIcon(
 						array_key_exists($problem['userid'], $data['users'])
 							? _s('Resolved by user "%1$s".', getUserFullname($data['users'][$problem['userid']]))
-							: _('Resolved by user.')
+							: _('Resolved by inaccessible user.')
 					);
 				}
 			}
@@ -290,8 +263,8 @@ class CScreenHostTriggers extends CScreenBase {
 				$host_name,
 				(new CCol([
 					(new CLinkAction($problem['name']))
-						->setHint(make_popup_eventlist(['comments' => $problem['comments']] + $trigger,
-							$problem['eventid'], $back_url
+						->setHint(make_popup_eventlist(['comments' => $problem['comments'], 'url' => $problem['url'],
+							'triggerid' => $trigger['triggerid']], $problem['eventid'], $back_url
 						))
 				]))->addClass(getSeverityStyle($problem['severity'])),
 				$clock,
