@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -34,10 +34,18 @@ class CNewValidator {
 	 */
 	private $validationRuleParser;
 
+	/**
+	 * Parser for range date/time.
+	 *
+	 * @var CRangeTimeParser
+	 */
+	private $range_time_parser;
+
 	public function __construct(array $input, array $rules) {
 		$this->input = $input;
 		$this->rules = $rules;
 		$this->validationRuleParser = new CValidationRule();
+		$this->range_time_parser = null;
 
 		$this->validate();
 	}
@@ -104,8 +112,9 @@ class CNewValidator {
 					if (array_key_exists($field, $this->input)) {
 						if (!is_string($this->input[$field]) || !in_array($this->input[$field], $params)) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -116,8 +125,9 @@ class CNewValidator {
 					if (array_key_exists($field, $this->input)) {
 						if (!is_string($this->input[$field]) || !$this->is_int32($this->input[$field])) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -128,8 +138,9 @@ class CNewValidator {
 					if (array_key_exists($field, $this->input)) {
 						if (!is_string($this->input[$field]) || !$this->is_id($this->input[$field])) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -143,8 +154,9 @@ class CNewValidator {
 					if (array_key_exists($field, $this->input)) {
 						if (!is_array($this->input[$field]) || !$this->is_array_id($this->input[$field])) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -172,11 +184,13 @@ class CNewValidator {
 				 */
 				case 'array_db':
 					if (array_key_exists($field, $this->input)) {
-						if (!$this->is_array_db($this->input[$field], $params['table'], $params['field'], $flags)
-								|| !is_array($this->input[$field])) {
+						if (!is_array($this->input[$field])
+								|| !$this->is_array_db($this->input[$field], $params['table'], $params['field'], $flags)
+						) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -225,8 +239,9 @@ class CNewValidator {
 					if (array_key_exists($field, $this->input)) {
 						if (!$this->is_db($this->input[$field], $params['table'], $params['field'], $flags)) {
 							$this->addError($fatal,
-								_s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
-								// TODO: stringify($this->input[$field]) ???
+								is_scalar($this->input[$field])
+									? _s('Incorrect value "%1$s" for "%2$s" field.', $this->input[$field], $field)
+									: _s('Incorrect value for "%1$s" field.', $field)
 							);
 							return false;
 						}
@@ -244,24 +259,24 @@ class CNewValidator {
 					break;
 
 				/*
-				 * 'string' => true
+				 * 'range_time' => true
 				 */
-				case 'string':
-					if (array_key_exists($field, $this->input) && !is_string($this->input[$field])) {
+				case 'range_time':
+					if (array_key_exists($field, $this->input) && !$this->isRangeTime($this->input[$field])) {
 						$this->addError($fatal,
-							_s('Incorrect value for field "%1$s": %2$s.', $field, _('a character string is expected'))
+							_s('Incorrect value for field "%1$s": %2$s.', $field, _('a time is expected'))
 						);
 						return false;
 					}
 					break;
 
 				/*
-				 * 'time' => true
+				 * 'string' => true
 				 */
-				case 'time':
-					if (array_key_exists($field, $this->input) && !$this->is_time($this->input[$field])) {
+				case 'string':
+					if (array_key_exists($field, $this->input) && !is_string($this->input[$field])) {
 						$this->addError($fatal,
-							_s('Incorrect value for field "%1$s": %2$s.', $field, _('a time is expected'))
+							_s('Incorrect value for field "%1$s": %2$s.', $field, _('a character string is expected'))
 						);
 						return false;
 					}
@@ -289,7 +304,7 @@ class CNewValidator {
 		}
 
 		// between 0 and _I64_MAX
-		return (bccomp($value, '0') >= 0 && bccomp($value, '9223372036854775807') <= 0);
+		return (bccomp($value, '0') >= 0 && bccomp($value, ZBX_DB_MAX_ID) <= 0);
 	}
 
 	public static function is_int32($value) {
@@ -414,22 +429,12 @@ class CNewValidator {
 		return 31;
 	}
 
-	private function is_time($value) {
-		// YYYYMMDDhhmmss
-
-		if (!is_string($value) || strlen($value) != 14 || !ctype_digit($value)) {
-			return false;
+	private function isRangeTime($value) {
+		if ($this->range_time_parser === null) {
+			$this->range_time_parser = new CRangeTimeParser();
 		}
 
-		$Y = (int) substr($value, 0, 4);
-		$M = (int) substr($value, 4, 2);
-		$D = (int) substr($value, 6, 2);
-		$h = (int) substr($value, 8, 2);
-		$m = (int) substr($value, 10, 2);
-		$s = (int) substr($value, 12, 2);
-
-		return ($Y >= 1990 && $M >= 1 && $M <= 12 && $D >= 1 && $D <= $this->getDaysInMonth($Y, $M)
-			&& $h >= 0 && $h <= 23 && $m >= 0 && $m <= 59 && $s >= 0 && $s <= 59);
+		return is_string($value) && $this->range_time_parser->parse($value) == CParser::PARSE_SUCCESS;
 	}
 
 	/**
