@@ -24,11 +24,12 @@ function getSounds() {
 	$dir = scandir('./audio');
 
 	foreach ($dir as $file) {
-		if ('audio/' !== substr(mime_content_type('./audio/'.$file), 0, 6)) {
+		$pos = strrpos($file, '.');
+		if ($pos === false || mb_strtolower(substr($file, $pos + 1)) !== 'mp3') {
 			continue;
 		}
 
-		$filename = explode('.', $file)[0];
+		$filename = substr($file, 0, $pos);
 		$file_list[$filename] = $file;
 	}
 
@@ -73,12 +74,13 @@ function getMessageSettings() {
 		$messages[$profile['source']] = $profile['value_str'];
 	}
 
-	if (is_null($messages['triggers.severities'])) {
+	if ($messages['triggers.severities'] === null) {
 		$messages['triggers.severities'] = $defSeverities;
 	}
 	else {
 		$messages['triggers.severities'] = unserialize($messages['triggers.severities']);
 	}
+
 	return $messages;
 }
 
