@@ -44,6 +44,7 @@ $user_type = CWebUser::getType();
 
 if ($user_type == USER_TYPE_SUPER_ADMIN) {
 	$titles['images'] = _('Images');
+	$titles['mediaTypes'] = _('Media types');
 	$titles['valueMaps'] = _('Value mappings');
 }
 
@@ -91,6 +92,12 @@ foreach ($titles as $key => $title) {
 				&& $user_type != USER_TYPE_ZABBIX_ADMIN) {
 			$cbDeleted->setAttribute('disabled', 'disabled');
 		}
+
+		if ($key === 'templateLinkage') {
+			$cbDeleted->onClick('updateWarning(this, '.CJs::encodeJson(
+				_('Template and host properties that are inherited through template linkage will be unlinked and cleared.')
+			).')');
+		}
 	}
 
 	$rulesTable->addRow([
