@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -44,13 +44,56 @@ $widget = (new CWidget())
 					->onClick('redirect("conf.import.php?rules_preset=host")')
 					->removeId()
 			)
-		))
-			->setAttribute('aria-label', _('Content controls'))
+		))->setAttribute('aria-label', _('Content controls'))
 	]));
 
+$filter_tags = $data['filter']['tags'];
+if (!$filter_tags) {
+	$filter_tags = [['tag' => '', 'value' => '', 'operator' => TAG_OPERATOR_LIKE]];
+}
+
+$filter_tags_table = (new CTable())
+	->setId('filter-tags')
+	->addRow((new CCol(
+		(new CRadioButtonList('filter_evaltype', (int) $data['filter']['evaltype']))
+			->addValue(_('And/Or'), TAG_EVAL_TYPE_AND_OR)
+			->addValue(_('Or'), TAG_EVAL_TYPE_OR)
+			->setModern(true)
+		))->setColSpan(4)
+	);
+
+$i = 0;
+foreach ($filter_tags as $tag) {
+	$filter_tags_table->addRow([
+		(new CTextBox('filter_tags['.$i.'][tag]', $tag['tag']))
+			->setAttribute('placeholder', _('tag'))
+			->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
+		(new CRadioButtonList('filter_tags['.$i.'][operator]', (int) $tag['operator']))
+			->addValue(_('Contains'), TAG_OPERATOR_LIKE)
+			->addValue(_('Equals'), TAG_OPERATOR_EQUAL)
+			->setModern(true),
+		(new CTextBox('filter_tags['.$i.'][value]', $tag['value']))
+			->setAttribute('placeholder', _('value'))
+			->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
+		(new CCol(
+			(new CButton('filter_tags['.$i.'][remove]', _('Remove')))
+				->addClass(ZBX_STYLE_BTN_LINK)
+				->addClass('element-table-remove')
+		))->addClass(ZBX_STYLE_NOWRAP)
+	], 'form_row');
+
+	$i++;
+}
+$filter_tags_table->addRow(
+	(new CCol(
+		(new CButton('filter_tags_add', _('Add')))
+			->addClass(ZBX_STYLE_BTN_LINK)
+			->addClass('element-table-add')
+	))->setColSpan(3)
+);
+
 // filter
 $filter = new CFilter(new CUrl('hosts.php'));
-
 $filter
 	->setProfile($data['profileIdx'])
 	->setActiveTab($data['active_tab'])
@@ -78,6 +121,16 @@ $filter
 					]
 				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			)
+			->addRow(_('DNS'),
+				(new CTextBox('filter_dns', $data['filter']['dns']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
+			->addRow(_('IP'),
+				(new CTextBox('filter_ip', $data['filter']['ip']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
+			->addRow(_('Port'),
+				(new CTextBox('filter_port', $data['filter']['port']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			),
+		(new CFormList())
 			->addRow(_('Monitored by'),
 				(new CRadioButtonList('filter_monitored_by', (int) $data['filter']['monitored_by']))
 					->addValue(_('Any'), ZBX_MONITORED_BY_ANY)
@@ -102,17 +155,8 @@ $filter
 						]
 					]
 				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
-			),
-		(new CFormList())
-			->addRow(_('DNS'),
-				(new CTextBox('filter_dns', $data['filter']['dns']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
-			)
-			->addRow(_('IP'),
-				(new CTextBox('filter_ip', $data['filter']['ip']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
-			)
-			->addRow(_('Port'),
-				(new CTextBox('filter_port', $data['filter']['port']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			)
+			->addRow(_('Tags'), $filter_tags_table)
 	]);
 
 $widget->addItem($filter);
@@ -133,11 +177,14 @@ $table = (new CTableInfo())
 		_('Discovery'),
 		_('Web'),
 		_('Interface'),
+		($data['filter']['monitored_by'] == ZBX_MONITORED_BY_PROXY
+				|| $data['filter']['monitored_by'] == ZBX_MONITORED_BY_ANY) ? _('Proxy') : null,
 		_('Templates'),
 		make_sorting_header(_('Status'), 'status', $data['sortField'], $data['sortOrder'], 'hosts.php'),
 		_('Availability'),
 		_('Agent encryption'),
-		_('Info')
+		_('Info'),
+		_('Tags')
 	]);
 
 $current_time = time();
@@ -157,36 +204,43 @@ foreach ($data['hosts'] as $host) {
 
 	$description = [];
 
-	if ($host['proxy_hostid'] != 0) {
-		$description[] = $data['proxies'][$host['proxy_hostid']]['host'];
-		$description[] = NAME_DELIMITER;
-	}
 	if ($host['discoveryRule']) {
-		$description[] = (new CLink(
-			$host['discoveryRule']['name'], 'host_prototypes.php?parent_discoveryid='.$host['discoveryRule']['itemid']
+		$description[] = (new CLink(CHtml::encode($host['discoveryRule']['name']),
+			(new CUrl('host_prototypes.php'))->setArgument('parent_discoveryid', $host['discoveryRule']['itemid'])
 		))
 			->addClass(ZBX_STYLE_LINK_ALT)
 			->addClass(ZBX_STYLE_ORANGE);
 		$description[] = NAME_DELIMITER;
 	}
+	elseif ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
+		// Discovered host which does not contain info about parent discovery rule is inaccessible for current user.
+		$description[] = (new CSpan(_('Inaccessible discovery rule')))->addClass(ZBX_STYLE_ORANGE);
+		$description[] = NAME_DELIMITER;
+	}
 
 	$description[] = new CLink(CHtml::encode($host['name']),
 		'hosts.php?form=update&hostid='.$host['hostid'].url_param('groupid')
 	);
 
+	$maintenance_icon = false;
 	$hostInterface = ($interface['useip'] == INTERFACE_USE_IP) ? $interface['ip'] : $interface['dns'];
 	$hostInterface .= empty($interface['port']) ? '' : NAME_DELIMITER.$interface['port'];
 
 	if ($host['status'] == HOST_STATUS_MONITORED) {
 		if ($host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON) {
-			$statusCaption = _('In maintenance');
-			$statusClass = ZBX_STYLE_ORANGE;
-		}
-		else {
-			$statusCaption = _('Enabled');
-			$statusClass = ZBX_STYLE_GREEN;
+			if (array_key_exists($host['maintenanceid'], $data['maintenances'])) {
+				$maintenance = $data['maintenances'][$host['maintenanceid']];
+				$maintenance_icon = makeMaintenanceIcon($host['maintenance_type'], $maintenance['name'],
+					$maintenance['description']
+				);
+			}
+			else {
+				$maintenance_icon = makeMaintenanceIcon($host['maintenance_type'], _('Inaccessible maintenance'), '');
+			}
 		}
 
+		$statusCaption = _('Enabled');
+		$statusClass = ZBX_STYLE_GREEN;
 		$confirm_message = _('Disable host?');
 		$statusUrl = 'hosts.php?hosts[]='.$host['hostid'].'&action=host.massdisable'.url_param('groupid');
 	}
@@ -203,6 +257,13 @@ foreach ($data['hosts'] as $host) {
 		->addConfirmation($confirm_message)
 		->addSID();
 
+	if ($maintenance_icon) {
+		$status = [$maintenance_icon, $status];
+	}
+	elseif (count($data['maintenances'])) {
+		$status->addClass(ZBX_STYLE_ICON_NONE);
+	}
+
 	order_result($host['parentTemplates'], 'name');
 
 	$hostTemplates = [];
@@ -219,8 +280,10 @@ foreach ($data['hosts'] as $host) {
 
 		if (array_key_exists($template['templateid'], $data['writable_templates'])) {
 			$caption = [
-				(new CLink(
-					CHtml::encode($template['name']), 'templates.php?form=update&templateid='.$template['templateid']
+				(new CLink(CHtml::encode($template['name']),
+					(new CUrl('templates.php'))
+						->setArgument('form', 'update')
+						->setArgument('templateid', $template['templateid'])
 				))
 					->addClass(ZBX_STYLE_LINK_ALT)
 					->addClass(ZBX_STYLE_GREY)
@@ -241,7 +304,9 @@ foreach ($data['hosts'] as $host) {
 			foreach ($parent_templates as $parent_template) {
 				if (array_key_exists($parent_template['templateid'], $data['writable_templates'])) {
 					$caption[] = (new CLink(CHtml::encode($parent_template['name']),
-						'templates.php?form=update&templateid='.$parent_template['templateid']
+						(new CUrl('templates.php'))
+							->setArgument('form', 'update')
+							->setArgument('templateid', $parent_template['templateid'])
 					))
 						->addClass(ZBX_STYLE_LINK_ALT)
 						->addClass(ZBX_STYLE_GREY);
@@ -321,11 +386,19 @@ foreach ($data['hosts'] as $host) {
 			CViewHelper::showNum($host['applications'])
 		],
 		[
-			new CLink(_('Items'), 'items.php?filter_set=1&hostid='.$host['hostid']),
+			new CLink(_('Items'),
+				(new CUrl('items.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$host['hostid']])
+			),
 			CViewHelper::showNum($host['items'])
 		],
 		[
-			new CLink(_('Triggers'), 'triggers.php?groupid='.$data['groupId'].'&hostid='.$host['hostid']),
+			new CLink(_('Triggers'),
+				(new CUrl('triggers.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$host['hostid']])
+			),
 			CViewHelper::showNum($host['triggers'])
 		],
 		[
@@ -341,11 +414,18 @@ foreach ($data['hosts'] as $host) {
 			CViewHelper::showNum($host['httpTests'])
 		],
 		$hostInterface,
+		($data['filter']['monitored_by'] == ZBX_MONITORED_BY_PROXY
+				|| $data['filter']['monitored_by'] == ZBX_MONITORED_BY_ANY)
+			? ($host['proxy_hostid'] != 0)
+				? $data['proxies'][$host['proxy_hostid']]['host']
+				: ''
+			: null,
 		$hostTemplates,
 		$status,
 		getHostAvailabilityTable($host),
 		$encryption,
-		makeInformationList($info_icons)
+		makeInformationList($info_icons),
+		$data['tags'][$host['hostid']]
 	]);
 }
 
@@ -356,7 +436,15 @@ $form->addItem([
 		[
 			'host.massenable' => ['name' => _('Enable'), 'confirm' => _('Enable selected hosts?')],
 			'host.massdisable' => ['name' => _('Disable'), 'confirm' => _('Disable selected hosts?')],
-			'host.export' => ['name' => _('Export')],
+			'host.export' => ['name' => _('Export'), 'redirect' =>
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'export.hosts.xml')
+					->setArgument('backurl', (new CUrl('hosts.php'))
+						->setArgument('groupid', $data['pageFilter']->groupid)
+						->setArgument('page', getPageNumber())
+						->getUrl())
+					->getUrl()
+			],
 			'host.massupdateform' => ['name' => _('Mass update')],
 			'host.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected hosts?')]
 		]
