@@ -249,6 +249,8 @@ elseif ($config == QUEUE_DETAILS) {
 		}
 	}
 
+	$proxies = [];
+
 	if ($proxyHostIds) {
 		$proxies = API::Proxy()->get([
 			'proxyids' => $proxyHostIds,
@@ -261,7 +263,8 @@ elseif ($config == QUEUE_DETAILS) {
 		_('Scheduled check'),
 		_('Delayed by'),
 		_('Host'),
-		_('Name')
+		_('Name'),
+		_('Proxy')
 	]);
 
 	$i = 0;
@@ -282,10 +285,11 @@ elseif ($config == QUEUE_DETAILS) {
 		$table->addRow([
 			zbx_date2str(DATE_TIME_FORMAT_SECONDS, $itemData['nextcheck']),
 			zbx_date2age($itemData['nextcheck']),
-			isset($proxies[$hosts[$item['hostid']]['proxy_hostid']])
-				? $proxies[$hosts[$item['hostid']]['proxy_hostid']]['host'].NAME_DELIMITER.$host['name']
-				: $host['name'],
-			$item['name_expanded']
+			$host['name'],
+			$item['name_expanded'],
+			array_key_exists($hosts[$item['hostid']]['proxy_hostid'], $proxies)
+				? $proxies[$hosts[$item['hostid']]['proxy_hostid']]['host']
+				: ''
 		]);
 	}
 }
